
# Twitter Sentiment Tracker
# Summer 2022 ACO 499

Tracks Twitter sentiment over time using Tweets that contain certain keywords and meet certain conditions.    
To Use:  
pip install twitsent  
Then call the keyword_search method when tweet collection is desired. After the collection is complete, a 
file containing a html file that displays the results and methods will be displayed in the user's default web
browser.

## Authors

- [Mitchell Hoikka](https://www.github.com/mhoikka)
